from django.conf import settings
from adminlte2_templates import constants


def _get_context(context):
    """
        Return the context from Django settings.
        If no context is found, get default value from module constants
    """
    return getattr(settings, context, getattr(constants, context))


def template(request):
    """
        Get all settings related to the AdminLTE 2 module and return them as context variables
    """
    skin_style = _get_context('ADMINLTE_SKIN_STYLE')

    context = {
        'DEBUG': getattr(settings, 'DEBUG'),

        #
        # HTML 'lang' attribute value
        #
        'ADMINLTE_HTML_LANG': _get_context('ADMINLTE_HTML_LANG'),

        #
        # Skin style color. Valid values are:
        #   skin-black, skin-black-light, skin-blue, skin-blue-light, skin-green, skin-green-light, skin-purple,
        #   skin-purple-light, skin-red, skin-red-light, skin-yellow, skin-yellow-light
        #
        'ADMINLTE_SKIN_STYLE': skin_style,

        #
        # Control sidebar color. Valid values are:
        #   control-sidebar-dark, control-sidebar-light
        #
        'ADMINLTE_CONTROL_STYLE': _get_context('ADMINLTE_CONTROL_STYLE'),

        #
        # Toggle to use HTML5 Shim
        #
        'ADMINLTE_USE_SHIM': _get_context('ADMINLTE_USE_SHIM'),

        #
        # Toggle to use CDN for AdminLTE dependencies
        #
        'ADMINLTE_USE_CDN': _get_context('ADMINLTE_USE_CDN'),

        #
        # Dependency CDN URLs
        #
        # AdminLTE 2.4.18
        'ADMINLTE_CDN_ADMINLTE_CSS_CORE': _get_context('ADMINLTE_CDN_ADMINLTE_CSS_CORE'),
        'ADMINLTE_CDN_ADMINLTE_CSS_SKIN': _get_context('ADMINLTE_CDN_ADMINLTE_CSS_SKIN')[skin_style],
        'ADMINLTE_CDN_ADMINLTE_JS_CORE': _get_context('ADMINLTE_CDN_ADMINLTE_JS_CORE'),
        # Bootstrap 3.4.1
        'ADMINLTE_CDN_BOOTSTRAP_CSS_CORE': _get_context('ADMINLTE_CDN_BOOTSTRAP_CSS_CORE'),
        'ADMINLTE_CDN_BOOTSTRAP_JS_CORE': _get_context('ADMINLTE_CDN_BOOTSTRAP_JS_CORE'),
        # Font-Awesome 4.7.0
        'ADMINLTE_CDN_FONTAWESOME_CSS_CORE': _get_context('ADMINLTE_CDN_FONTAWESOME_CSS_CORE'),
        # jQuery 3.4.1
        'ADMINLTE_CDN_JQUERY_JS_CORE': _get_context('ADMINLTE_CDN_JQUERY_JS_CORE'),
        # Shims
        'ADMINLTE_CDN_HTML5SHIV_CORE_JS': _get_context('ADMINLTE_CDN_HTML5SHIV_CORE_JS'),
        'ADMINLTE_CDN_RESPOND_CORE_JS': _get_context('ADMINLTE_CDN_RESPOND_CORE_JS'),
    }

    return context



from django import template
from django.shortcuts import reverse

register = template.Library()


@register.simple_tag(takes_context=True)
def add_active(context, url_pattern, *args, **kwargs):
    """
    Add class ``active`` to sidebar and header navigation links based on comparison of URL pattern with current URL.

    Based on django-adminlte2 templatetags
     https://github.com/adamcharnock/django-adminlte2/tree/master/django_adminlte/templatetags.

        :param context: Current context
        :type context: obj

        :param url_pattern: URL pattern for ``reverse`` matching
        :type url_pattern: str

        :param exact_match: Toggle for exact matching, defaults to False
        :type exact_match: bool, optional

        :param not_when: Comma-separated values of string patterns
            that will render comparison as False, defaults to ''
        :type not_when: str, optional

        :param args: Positional arguments for ``reverse`` matching
        :type args: tuple

        :params kwargs: Keyword arguments for ``reverse`` matching
        :type kwargs: dict

        :return: 'active' if comparison is True, else ''
        :rtype: str
    """
    exact_match = kwargs.pop('exact_match', False)
    not_when = kwargs.pop('not_when', '').split(',')
    not_when = [nw.strip() for nw in not_when if nw.strip()]

    path = reverse(url_pattern, args=args, kwargs=kwargs)
    current_path = context.request.path

    if not_when and any(nw in current_path for nw in not_when):
        return ''

    if not exact_match and current_path.startswith(path):
        return ' active '
    elif exact_match and current_path == path:
        return ' active '
    else:
        return ''



ADMINLTE_HTML_LANG = 'en'
"""
    *(str)* HTML 'lang' attribute value.
    
    Defaults to ``'en'``
"""

ADMINLTE_USE_SHIM = False
"""
    *(bool)* Toggle to use HTML5 Shim for IE9 support.
    
    Defaults to ``False``.
"""

ADMINLTE_USE_CDN = False
"""
    *(bool)* Toggle to use CDN links for AdminLTE dependencies.
    
    Defaults to ``False``.
"""

ADMINLTE_CDN_ADMINLTE_CSS_CORE = 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/AdminLTE.min.css'
"""
    *(str)* CDN link for AdminLTE 2.4.18 core CSS file.
    
    Defaults to ``'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/AdminLTE.min.css'``.
"""

ADMINLTE_CDN_ADMINLTE_CSS_SKIN = {
    'skin-black': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-black.min.css',
    'skin-black-light': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-black-light.min.css',
    'skin-blue': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-blue.min.css',
    'skin-blue-light': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-blue-light.min.css',
    'skin-green': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-green.min.css',
    'skin-green-light': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-green-light.min.css',
    'skin-purple': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-purple.min.css',
    'skin-purple-light': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-purple-light.min.css',
    'skin-red': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-red.min.css',
    'skin-red-light': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-red-light.min.css',
    'skin-yellow': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-yellow.min.css',
    'skin-yellow-light': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-yellow-light.min.css',
}
"""
    *(dict)* CDN links for AdminLTE 2.4.18 skin CSS files.
    
    Valid keys are: ``'skin-black'``, ``'skin-black-light'``, ``'skin-blue'``, ``'skin-blue-light'``,
    ``'skin-green'``, ``'skin-green-light'``, ``'skin-purple'``, ``'skin-purple-light'``,
    ``'skin-red'``, ``'skin-red-light'``, ``'skin-yellow'``, ``'skin-yellow-light'``.
    
    Default:
    
    .. code:: python
    
        {
            'skin-black': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-black.min.css',
            'skin-black-light': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-black-light.min.css',
            'skin-blue': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-blue.min.css',
            'skin-blue-light': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-blue-light.min.css',
            'skin-green': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-green.min.css',
            'skin-green-light': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-green-light.min.css',
            'skin-purple': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-purple.min.css',
            'skin-purple-light': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-purple-light.min.css',
            'skin-red': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-red.min.css',
            'skin-red-light': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-red-light.min.css',
            'skin-yellow': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-yellow.min.css',
            'skin-yellow-light': 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/css/skins/skin-yellow-light.min.css',
        }
"""

ADMINLTE_CDN_ADMINLTE_JS_CORE = 'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/js/adminlte.min.js'
"""
    *(str)* CDN link for AdminLTE 2.4.18 core JS file.
    
    Defaults to ``'https://cdnjs.cloudflare.com/ajax/libs/admin-lte/2.4.18/js/adminlte.min.js'``.
"""

ADMINLTE_CDN_BOOTSTRAP_CSS_CORE = 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.4.1/css/bootstrap.min.css'
"""
    *(str)* CDN link for Bootstrap 3.4.1 core CSS file.
    
    Defaults to ``'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.4.1/css/bootstrap.min.css'``.
"""

ADMINLTE_CDN_BOOTSTRAP_JS_CORE = 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.4.1/js/bootstrap.min.js'
"""
    *(str)* CDN link for Bootstrap 3.4.1 core JS file.
    
    Defaults to ``'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.4.1/js/bootstrap.min.js'``.
"""

ADMINLTE_CDN_FONTAWESOME_CSS_CORE = 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css'
"""
    *(str)* CDN link for Font-Awesome 4.7.0 core CSS file.
    
    Defaults to ``'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css'``.
"""

ADMINLTE_CDN_JQUERY_JS_CORE = 'https://cdnjs.cloudflare.com/ajax/libs/jquery/3.4.1/jquery.min.js'
"""
    *(str)* CDN link for jQuery 3.4.1 JS file.
    
    Defaults to ``'https://cdnjs.cloudflare.com/ajax/libs/jquery/3.4.1/jquery.min.js'``.
"""

ADMINLTE_CDN_HTML5SHIV_CORE_JS = 'https://oss.maxcdn.com/html5shiv/3.7.3/html5shiv.min.js'
"""
    *(str)* CDN link for HTML5 Shim script HTML5 Shiv JS file.
    
    Defaults to ``https://oss.maxcdn.com/html5shiv/3.7.3/html5shiv.min.js``.
"""

ADMINLTE_CDN_RESPOND_CORE_JS = 'https://oss.maxcdn.com/respond/1.4.2/respond.min.js'
"""
    *(str)* CDN link for HTML5 Shim script Respond JS file.
    
    Defaults to ``https://oss.maxcdn.com/respond/1.4.2/respond.min.js``.
"""

# Valid AdminLTE skin style values
SKIN_STYLE_BLACK = 'skin-black'
SKIN_STYLE_BLACK_LIGHT = 'skin-black-light'
SKIN_STYLE_BLUE = 'skin-blue'
SKIN_STYLE_BLUE_LIGHT = 'skin-blue-light'
SKIN_STYLE_GREEN = 'skin-green'
SKIN_STYLE_GREEN_LIGHT = 'skin-green-light'
SKIN_STYLE_PURPLE = 'skin-purple'
SKIN_STYLE_PURPLE_LIGHT = 'skin-purple-light'
SKIN_STYLE_RED = 'skin-red'
SKIN_STYLE_RED_LIGHT = 'skin-red-light'
SKIN_STYLE_YELLOW = 'skin-yellow'
SKIN_STYLE_YELLOW_LIGHT = 'skin-yellow-light'
SKIN_STYLE_CHOICES = (SKIN_STYLE_BLACK, SKIN_STYLE_BLACK_LIGHT, SKIN_STYLE_BLUE, SKIN_STYLE_BLUE_LIGHT,
                      SKIN_STYLE_GREEN, SKIN_STYLE_GREEN_LIGHT, SKIN_STYLE_PURPLE, SKIN_STYLE_PURPLE_LIGHT,
                      SKIN_STYLE_RED, SKIN_STYLE_RED_LIGHT, SKIN_STYLE_YELLOW, SKIN_STYLE_YELLOW_LIGHT)

ADMINLTE_SKIN_STYLE = SKIN_STYLE_BLUE
"""
    *(str)* Default AdminLTE skin style.
    
    Valid values are: ``'skin-black'``, ``'skin-black-light'``, ``'skin-blue'``, ``'skin-blue-light'``,
    ``'skin-green'``, ``'skin-green-light'``, ``'skin-purple'``, ``'skin-purple-light'``,
    ``'skin-red'``, ``'skin-red-light'``, ``'skin-yellow'``, ``'skin-yellow-light'``.
    
    Defaults to ``'skin-blue'``.
"""

CONTROL_STYLE_DARK = 'control-sidebar-dark'
CONTROL_STYLE_LIGHT = 'control-sidebar-light'
CONTROL_STYLE_CHOICES = (CONTROL_STYLE_DARK, CONTROL_STYLE_LIGHT)

ADMINLTE_CONTROL_STYLE = CONTROL_STYLE_DARK
"""
    *(str)* Default AdminLTE control sidebar style.
    
    Valid values are: ``'control-sidebar-dark'``, ``'control-sidebar-light'``.
    
    Defaults to ``'control-sidebar-dark'``.
"""
